===========
Development
===========

Thank you for your interest in contributing to Virtue.  If you have a feature
you'd be interested in seeing added to Virtue, please start by describing it
in the issue tracker.  Others may have experience with the issue and can help
determine the best course of action.

If a feature needs to be added, then a pull request can be created.
Please follow the guidelines so we can efficiently merge your contibutions.
Once the pull-request is ready, it will need to be reviewed by at least one
member of cascod-labs.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :hidden:

   getting_started
